==> extended-listbox-3.0.0.tgz: package/README.md <==
# Extended Listbox

[![Travis](https://img.shields.io/travis/code-chris/extended-listbox.svg?branch=master)](https://travis-ci.org/code-chris/extended-listbox?branch=master)
[![NPM](https://img.shields.io/npm/v/extended-listbox.svg)](https://www.npmjs.com/package/extended-listbox)
[![David](https://img.shields.io/david/code-chris/extended-listbox.svg)](https://david-dm.org/code-chris/extended-listbox)
[![David](https://img.shields.io/david/dev/code-chris/extended-listbox.svg)](https://david-dm.org/code-chris/extended-listbox)
[![Greenkeeper badge](https://badges.greenkeeper.io/code-chris/extended-listbox.svg)](https://greenkeeper.io/)


**Extended Listbox** is a simple to use jQuery plugin as powerful
alternative to the HTML `<select>` tag. The main problem of
`<select>` tag is that last one isn’t flexible for customization with
*CSS*. Extended Listbox solves this problem. This component creates a list
structure based on `<div>` tags. The configuration is completely in
JavaScript. It opens up great possibilities for customization.

In addition, this component provides other useful features like a search
bar or group items.


## Supported Browsers

- IE 11
- Edge latest
- Chrome latest
- Firefox latest


## Installation

Install with NPM:
```
npm install extended-listbox
```
Install TypeScript Definitions:
```
typings install github:code-chris/extended-listbox --global
```


## Usage

Link the component and a stylesheet from your page.

```html
<!-- make sure that jQuery is already included -->
<script src="/path/to/jquery.js"></script>

<!-- include listbox plugin and default stylesheet -->
<link href="/path/to/extended-listbox.css" rel="stylesheet">
<script src="/path/to/extended-listbox.js"></script>
```

## Size

| Type                             | Size     |
|----------------------------------|----------|
| Uncompressed, not minified       | 30,2 KB  |
| Uncompressed, minified           | 12,0 KB  |
| Compressed (gzip), not minified  | 5,2 KB   |
| Compressed (gzip), minified      | 3,4 KB   |


[Documentation](http://code-chris.github.io/extended-listbox/documentation/latest/)
--------------
[License](https://github.com/code-chris/extended-listbox/blob/master/LICENSE)
--------
[Changelog](https://github.com/code-chris/extended-listbox/blob/master/doc/CHANGELOG.md)
----------
[Roadmap](https://github.com/code-chris/extended-listbox/blob/master/doc/ROADMAP.md)
--------

==> extended-listbox-4.0.2.tgz: package/README.md <==
# Extended Listbox

[![Travis](https://img.shields.io/travis/code-chris/extended-listbox.svg?branch=master)](https://travis-ci.org/code-chris/extended-listbox?branch=master)
[![NPM](https://img.shields.io/npm/v/extended-listbox.svg)](https://www.npmjs.com/package/extended-listbox)
[![David](https://img.shields.io/david/code-chris/extended-listbox.svg)](https://david-dm.org/code-chris/extended-listbox)
[![David](https://img.shields.io/david/dev/code-chris/extended-listbox.svg)](https://david-dm.org/code-chris/extended-listbox)
[![Greenkeeper badge](https://badges.greenkeeper.io/code-chris/extended-listbox.svg)](https://greenkeeper.io/)


**Extended Listbox** is a simple to use javascript component as powerful
alternative to the HTML `<select>` tag. The main problem of
`<select>` tag is that last one isn’t flexible for customization with
*CSS*. Extended Listbox solves this problem. This component creates a list
structure based on `<div>` tags. The configuration is completely in
JavaScript. It opens up great possibilities for customization. **No jquery is needed**.

In addition, this component provides other useful features like a search
bar or grouped items.


## Supported Browsers

- IE 11
- Edge latest
- Chrome latest
- Firefox latest


## Installation

Install with NPM:
```
npm install extended-listbox
```
TypeScript definitions are included in the npm package.


## Usage

Link the component and a stylesheet from your page.

```html

<!-- include javascript and stylesheet -->
<link href="/path/to/extended-listbox.css" rel="stylesheet">
<script src="/path/to/extended-listbox.js"></script>
```

## Size

| Type                             | Size     |
|----------------------------------|----------|
| Uncompressed, not minified       | 31,3 KB  |
| Uncompressed, minified           | 13,5 KB  |
| Compressed (gzip), not minified  | 5,3 KB   |
| Compressed (gzip), minified      | 3,5 KB   |


[Documentation](http://code-chris.github.io/extended-listbox/documentation/latest/)
--------------
[License](https://github.com/code-chris/extended-listbox/blob/master/LICENSE)
--------
[Changelog](https://github.com/code-chris/extended-listbox/blob/master/doc/CHANGELOG.md)
----------
[Roadmap](https://github.com/code-chris/extended-listbox/blob/master/doc/ROADMAP.md)
--------
